@@ -15,23 +15,39 @@ class Client(object):
         if debug == True:
             print('Attempted connection to the database.')
 
-    def createVanity(self, vanityLink: str, ownerId: str, callbackUrl: str):
+    def createVanity(self, vanityId: str, ownerId: str, callbackUrl: str):
         if self.mongoDb is None:
             return print('Error: No mongoUri defined...')
         else:
             url = {
-                "vanityLink": str(vanityLink),
+                "vanityId": str(vanityId),
                 "callback": str(callbackUrl),
                 "ownerId": str(ownerId),
                 "disabled": False
             }
-            existing = self.db.urls.find_one({ "vanityLink": vanityLink })
+            existing = self.db.urls.find_one({ "vanityId": vanityId })
             if existing is None:
                 self.db.urls.insert_one(url)
-                self.db.users.find_one({ "vanityLink": vanityLink })
-                return f"Vanity created: {vanityLink}"
+                self.db.urls.find_one({ "vanityId": vanityId })
+                return f"New Vanity available at the following Id: {vanityId}"
             else:
-                return print('VanityLink already exists!')
+                return print('VanityId already exists!')
+
+    def getVanityById(self, vanityId):
+        if self.mongoDb is None:
+            return print('Error: no mongoUri defined...')
+        else:
+            vanity = self.db.urls.find_one({ "vanityId": vanityId })
+            if vanity is None:
+                if self.debugMode == True:
+                    print('Vanity not found!')
+                return "Vanity is not found!"
+            else:
+                if self.debugMode == True:
+                    print(f"Raw data found: {vanity}")
+                return objects.vanityData(json.loads(vanity)["vanity"])
+                
+
         # headers = {
         #     "Authorization": apiKey
         # }
